GoogleFirestoreAdminV1Backup

Struct GoogleFirestoreAdminV1Backup 

pub struct GoogleFirestoreAdminV1Backup {
    pub database: Option<String>,
    pub database_uid: Option<String>,
    pub expire_time: Option<DateTime<Utc>>,
    pub name: Option<String>,
    pub snapshot_time: Option<DateTime<Utc>>,
    pub state: Option<String>,
    pub stats: Option<GoogleFirestoreAdminV1Stats>,
}
A Backup of a Cloud Firestore Database. The backup contains all documents and index configurations for the given database at a specific point in time.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

database: Option<String>

Output only. Name of the Firestore database that the backup is from. Format is projects/{project}/databases/{database}.

database_uid: Option<String>

Output only. The system-generated UUID4 for the Firestore database that the backup is from.

expire_time: Option<DateTime<Utc>>

Output only. The timestamp at which this backup expires.

name: Option<String>

Output only. The unique resource name of the Backup. Format is projects/{project}/locations/{location}/backups/{backup}.

snapshot_time: Option<DateTime<Utc>>

Output only. The backup contains an externally consistent copy of the database at this time.

state: Option<String>

Output only. The current state of the backup.

stats: Option<GoogleFirestoreAdminV1Stats>

Output only. Statistics about the backup. This data only becomes available after the backup is fully materialized to secondary storage. This field will be empty till then.