pub struct GoogleFirestoreAdminV1BackupSource {
pub backup: Option<String>,
}Expand description
Information about a backup that was used to restore a database.
This type is not used in any activity, and only used as part of another schema.
Fields
backup: Option<String>The resource name of the backup that was used to restore this database. Format: projects/{project}/locations/{location}/backups/{backup}.