GoogleFirestoreAdminV1CustomerManagedEncryptionOptions

Struct GoogleFirestoreAdminV1CustomerManagedEncryptionOptions 

pub struct GoogleFirestoreAdminV1CustomerManagedEncryptionOptions {
    pub kms_key_name: Option<String>,
}
The configuration options for using CMEK (Customer Managed Encryption Key) encryption.

This type is not used in any activity, and only used as part of another schema.

Fields

kms_key_name: Option<String>

Required. Only keys in the same location as the database are allowed to be used for encryption. For Firestore’s nam5 multi-region, this corresponds to Cloud KMS multi-region us. For Firestore’s eur3 multi-region, this corresponds to Cloud KMS multi-region europe. See https://cloud.google.com/kms/docs/locations. The expected format is projects/{project_id}/locations/{kms_location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.