pub struct GoogleFirestoreAdminV1Database {Show 24 fields
pub app_engine_integration_mode: Option<String>,
pub cmek_config: Option<GoogleFirestoreAdminV1CmekConfig>,
pub concurrency_mode: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub database_edition: Option<String>,
pub delete_protection_state: Option<String>,
pub delete_time: Option<DateTime<Utc>>,
pub earliest_version_time: Option<DateTime<Utc>>,
pub etag: Option<String>,
pub firestore_data_access_mode: Option<String>,
pub free_tier: Option<bool>,
pub key_prefix: Option<String>,
pub location_id: Option<String>,
pub mongodb_compatible_data_access_mode: Option<String>,
pub name: Option<String>,
pub point_in_time_recovery_enablement: Option<String>,
pub previous_id: Option<String>,
pub realtime_updates_mode: Option<String>,
pub source_info: Option<GoogleFirestoreAdminV1SourceInfo>,
pub tags: Option<HashMap<String, String>>,
pub type_: Option<String>,
pub uid: Option<String>,
pub update_time: Option<DateTime<Utc>>,
pub version_retention_period: Option<Duration>,
}Expand description
A Cloud Firestore Database.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- databases create projects (request)
- databases get projects (response)
- databases patch projects (request)
Fields
app_engine_integration_mode: Option<String>The App Engine integration mode to use for this database.
cmek_config: Option<GoogleFirestoreAdminV1CmekConfig>Optional. Presence indicates CMEK is enabled for this database.
concurrency_mode: Option<String>The concurrency control mode to use for this database. If unspecified in a CreateDatabase request, this will default based on the database edition: Optimistic for Enterprise and Pessimistic for all other databases.
create_time: Option<DateTime<Utc>>Output only. The timestamp at which this database was created. Databases created before 2016 do not populate create_time.
database_edition: Option<String>Immutable. The edition of the database.
delete_protection_state: Option<String>State of delete protection for the database.
delete_time: Option<DateTime<Utc>>Output only. The timestamp at which this database was deleted. Only set if the database has been deleted.
earliest_version_time: Option<DateTime<Utc>>Output only. The earliest timestamp at which older versions of the data can be read from the database. See [version_retention_period] above; this field is populated with now - version_retention_period. This value is continuously updated, and becomes stale the moment it is queried. If you are using this value to recover data, make sure to account for the time from the moment when the value is queried to the moment when you initiate the recovery.
etag: Option<String>This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
firestore_data_access_mode: Option<String>Optional. The Firestore API data access mode to use for this database. If not set on write: - the default value is DATA_ACCESS_MODE_DISABLED for Enterprise Edition. - the default value is DATA_ACCESS_MODE_ENABLED for Standard Edition.
free_tier: Option<bool>Output only. Background: Free tier is the ability of a Firestore database to use a small amount of resources every day without being charged. Once usage exceeds the free tier limit further usage is charged. Whether this database can make use of the free tier. Only one database per project can be eligible for the free tier. The first (or next) database that is created in a project without a free tier database will be marked as eligible for the free tier. Databases that are created while there is a free tier database will not be eligible for the free tier.
key_prefix: Option<String>Output only. The key_prefix for this database. This key_prefix is used, in combination with the project ID (“~”) to construct the application ID that is returned from the Cloud Datastore APIs in Google App Engine first generation runtimes. This value may be empty in which case the appid to use for URL-encoded keys is the project_id (eg: foo instead of v~foo).
location_id: Option<String>The location of the database. Available locations are listed at https://cloud.google.com/firestore/docs/locations.
mongodb_compatible_data_access_mode: Option<String>Optional. The MongoDB compatible API data access mode to use for this database. If not set on write, the default value is DATA_ACCESS_MODE_ENABLED for Enterprise Edition. The value is always DATA_ACCESS_MODE_DISABLED for Standard Edition.
name: Option<String>The resource name of the Database. Format: projects/{project}/databases/{database}
point_in_time_recovery_enablement: Option<String>Whether to enable the PITR feature on this database.
previous_id: Option<String>Output only. The database resource’s prior database ID. This field is only populated for deleted databases.
realtime_updates_mode: Option<String>Immutable. The default Realtime Updates mode to use for this database.
source_info: Option<GoogleFirestoreAdminV1SourceInfo>Output only. Information about the provenance of this database.
Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: “123/environment”: “production”, “123/costCenter”: “marketing”
type_: Option<String>The type of the database. See https://cloud.google.com/datastore/docs/firestore-or-datastore for information about how to choose.
uid: Option<String>Output only. The system-generated UUID4 for this Database.
update_time: Option<DateTime<Utc>>Output only. The timestamp at which this database was most recently updated. Note this only includes updates to the database resource and not data contained by the database.
version_retention_period: Option<Duration>Output only. The period during which past versions of data are retained in the database. Any read or query can specify a read_time within this window, and will read the state of the database at that time. If the PITR feature is enabled, the retention period is 7 days. Otherwise, the retention period is 1 hour.