pub struct GoogleFirestoreAdminV1EncryptionConfig {
pub customer_managed_encryption: Option<GoogleFirestoreAdminV1CustomerManagedEncryptionOptions>,
pub google_default_encryption: Option<GoogleFirestoreAdminV1GoogleDefaultEncryptionOptions>,
pub use_source_encryption: Option<GoogleFirestoreAdminV1SourceEncryptionOptions>,
}Expand description
Encryption configuration for a new database being created from another source. The source could be a Backup or a PitrSnapshot.
This type is not used in any activity, and only used as part of another schema.
Fields
customer_managed_encryption: Option<GoogleFirestoreAdminV1CustomerManagedEncryptionOptions>Use Customer Managed Encryption Keys (CMEK) for encryption.
google_default_encryption: Option<GoogleFirestoreAdminV1GoogleDefaultEncryptionOptions>Use Google default encryption.
use_source_encryption: Option<GoogleFirestoreAdminV1SourceEncryptionOptions>The database will use the same encryption configuration as the source.