pub struct GoogleFirestoreAdminV1ExportDocumentsRequest {
pub collection_ids: Option<Vec<String>>,
pub namespace_ids: Option<Vec<String>>,
pub output_uri_prefix: Option<String>,
pub snapshot_time: Option<DateTime<Utc>>,
}Expand description
The request for FirestoreAdmin.ExportDocuments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- databases export documents projects (request)
Fields
collection_ids: Option<Vec<String>>IDs of the collection groups to export. Unspecified means all collection groups. Each collection group in this list must be unique.
namespace_ids: Option<Vec<String>>An empty list represents all namespaces. This is the preferred usage for databases that don’t use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn’t want to include them. Each namespace in this list must be unique.
output_uri_prefix: Option<String>The output URI. Currently only supports Google Cloud Storage URIs of the form: gs://BUCKET_NAME[/NAMESPACE_PATH], where BUCKET_NAME is the name of the Google Cloud Storage bucket and NAMESPACE_PATH is an optional Google Cloud Storage namespace path. When choosing a name, be sure to consider Google Cloud Storage naming guidelines: https://cloud.google.com/storage/docs/naming. If the URI is a bucket (without a namespace path), a prefix will be generated based on the start time.
snapshot_time: Option<DateTime<Utc>>The timestamp that corresponds to the version of the database to be exported. The timestamp must be in the past, rounded to the minute and not older than earliestVersionTime. If specified, then the exported documents will represent a consistent view of the database at the provided time. Otherwise, there are no guarantees about the consistency of the exported documents.