GoogleFirestoreAdminV1Field

Struct GoogleFirestoreAdminV1Field 

pub struct GoogleFirestoreAdminV1Field {
    pub index_config: Option<GoogleFirestoreAdminV1IndexConfig>,
    pub name: Option<String>,
    pub ttl_config: Option<GoogleFirestoreAdminV1TtlConfig>,
}
Represents a single field in the database. Fields are grouped by their “Collection Group”, which represent all collections in the database with the same ID.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

index_config: Option<GoogleFirestoreAdminV1IndexConfig>

The index configuration for this field. If unset, field indexing will revert to the configuration defined by the ancestor_field. To explicitly remove all indexes for this field, specify an index config with an empty list of indexes.

name: Option<String>

Required. A field name of the form: projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/fields/{field_path} A field path can be a simple field name, e.g. address or a path to fields within map_value , e.g. address.city, or a special field path. The only valid special field is *, which represents any field. Field paths can be quoted using ` (backtick). The only character that must be escaped within a quoted field path is the backtick character itself, escaped using a backslash. Special characters in field paths that must be quoted include: *, ., ` (backtick), [, ], as well as any ascii symbolic characters. Examples: `address.city` represents a field named address.city, not the map key city in the field address. `*` represents a field named *, not any field. A special Field contains the default indexing settings for all fields. This field’s resource name is: projects/{project_id}/databases/{database_id}/collectionGroups/__default__/fields/* Indexes defined on this Field will be applied to all fields which do not have their own Field index configuration.

ttl_config: Option<GoogleFirestoreAdminV1TtlConfig>

The TTL configuration for this Field. Setting or unsetting this will enable or disable the TTL for documents that have this Field.