GoogleFirestoreAdminV1FlatIndex

Struct GoogleFirestoreAdminV1FlatIndex 

pub struct GoogleFirestoreAdminV1FlatIndex { /* private fields */ }
An index that stores vectors in a flat data structure, and supports exhaustive search.

This type is not used in any activity, and only used as part of another schema.