pub struct GoogleFirestoreAdminV1ImportDocumentsRequest {
pub collection_ids: Option<Vec<String>>,
pub input_uri_prefix: Option<String>,
pub namespace_ids: Option<Vec<String>>,
}Expand description
The request for FirestoreAdmin.ImportDocuments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- databases import documents projects (request)
Fields
collection_ids: Option<Vec<String>>IDs of the collection groups to import. Unspecified means all collection groups that were included in the export. Each collection group in this list must be unique.
input_uri_prefix: Option<String>Location of the exported files. This must match the output_uri_prefix of an ExportDocumentsResponse from an export that has completed successfully. See: google.firestore.admin.v1.ExportDocumentsResponse.output_uri_prefix.
namespace_ids: Option<Vec<String>>An empty list represents all namespaces. This is the preferred usage for databases that don’t use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn’t want to include them. Each namespace in this list must be unique.