GoogleFirestoreAdminV1IndexConfig

Struct GoogleFirestoreAdminV1IndexConfig 

pub struct GoogleFirestoreAdminV1IndexConfig {
    pub ancestor_field: Option<String>,
    pub indexes: Option<Vec<GoogleFirestoreAdminV1Index>>,
    pub reverting: Option<bool>,
    pub uses_ancestor_config: Option<bool>,
}
The index configuration for this field.

This type is not used in any activity, and only used as part of another schema.

Fields

ancestor_field: Option<String>

Output only. Specifies the resource name of the Field from which this field’s index configuration is set (when uses_ancestor_config is true), or from which it would be set if this field had no index configuration (when uses_ancestor_config is false).

indexes: Option<Vec<GoogleFirestoreAdminV1Index>>

The indexes supported for this field.

reverting: Option<bool>

Output only When true, the Field’s index configuration is in the process of being reverted. Once complete, the index config will transition to the same state as the field specified by ancestor_field, at which point uses_ancestor_config will be true and reverting will be false.

uses_ancestor_config: Option<bool>

Output only. When true, the Field’s index configuration is set from the configuration specified by the ancestor_field. When false, the Field’s index configuration is defined explicitly.