pub struct GoogleFirestoreAdminV1IndexField {
pub array_config: Option<String>,
pub field_path: Option<String>,
pub order: Option<String>,
pub vector_config: Option<GoogleFirestoreAdminV1VectorConfig>,
}Expand description
A field in an index. The field_path describes which field is indexed, the value_mode describes how the field value is indexed.
This type is not used in any activity, and only used as part of another schema.
Fields
array_config: Option<String>Indicates that this field supports operations on array_values.
field_path: Option<String>Can be name. For single field indexes, this must match the name of the field or may be omitted.
order: Option<String>Indicates that this field supports ordering by the specified order or comparing using =, !=, <, <=, >, >=.
vector_config: Option<GoogleFirestoreAdminV1VectorConfig>Indicates that this field supports nearest neighbor and distance operations on vector.