pub struct GoogleFirestoreAdminV1ListBackupsResponse {
pub backups: Option<Vec<GoogleFirestoreAdminV1Backup>>,
pub unreachable: Option<Vec<String>>,
}Expand description
The response for FirestoreAdmin.ListBackups.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations backups list projects (response)
Fields
backups: Option<Vec<GoogleFirestoreAdminV1Backup>>List of all backups for the project.
unreachable: Option<Vec<String>>List of locations that existing backups were not able to be fetched from. Instead of failing the entire requests when a single location is unreachable, this response returns a partial result set and list of locations unable to be reached here. The request can be retried against a single location to get a concrete error.