pub struct GoogleFirestoreAdminV1ListDatabasesResponse {
pub databases: Option<Vec<GoogleFirestoreAdminV1Database>>,
pub unreachable: Option<Vec<String>>,
}Expand description
The list of databases for a project.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- databases list projects (response)
Fields
databases: Option<Vec<GoogleFirestoreAdminV1Database>>The databases in the project.
unreachable: Option<Vec<String>>In the event that data about individual databases cannot be listed they will be recorded here. An example entry might be: projects/some_project/locations/some_location This can happen if the Cloud Region that the Database resides in is currently unavailable. In this case we can’t fetch all the details about the database. You may be able to get a more detailed error message (or possibly fetch the resource) by sending a ‘Get’ request for the resource or a ‘List’ request for the specific location.