pub struct GoogleFirestoreAdminV1PitrSnapshot {
pub database: Option<String>,
pub database_uid: Option<Vec<u8>>,
pub snapshot_time: Option<DateTime<Utc>>,
}Expand description
A consistent snapshot of a database at a specific point in time. A PITR (Point-in-time recovery) snapshot with previous versions of a database’s data is available for every minute up to the associated database’s data retention period. If the PITR feature is enabled, the retention period is 7 days; otherwise, it is one hour.
This type is not used in any activity, and only used as part of another schema.
Fields
database: Option<String>Required. The name of the database that this was a snapshot of. Format: projects/{project}/databases/{database}.
database_uid: Option<Vec<u8>>Output only. Public UUID of the database the snapshot was associated with.
snapshot_time: Option<DateTime<Utc>>Required. Snapshot time of the database.