GoogleFirestoreAdminV1RestoreDatabaseRequest

Struct GoogleFirestoreAdminV1RestoreDatabaseRequest 

pub struct GoogleFirestoreAdminV1RestoreDatabaseRequest {
    pub backup: Option<String>,
    pub database_id: Option<String>,
    pub encryption_config: Option<GoogleFirestoreAdminV1EncryptionConfig>,
    pub tags: Option<HashMap<String, String>>,
}
The request message for FirestoreAdmin.RestoreDatabase.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

backup: Option<String>

Required. Backup to restore from. Must be from the same project as the parent. The restored database will be created in the same location as the source backup. Format is: projects/{project_id}/locations/{location}/backups/{backup}

database_id: Option<String>

Required. The ID to use for the database, which will become the final component of the database’s resource name. This database ID must not be associated with an existing database. This value should be 4-63 characters. Valid characters are /a-z-/ with first character a letter and the last a letter or a number. Must not be UUID-like /[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}/. “(default)” database ID is also valid if the database is Standard edition.

encryption_config: Option<GoogleFirestoreAdminV1EncryptionConfig>

Optional. Encryption configuration for the restored database. If this field is not specified, the restored database will use the same encryption configuration as the backup, namely use_source_encryption.

tags: Option<HashMap<String, String>>

Optional. Immutable. Tags to be bound to the restored database. The tags should be provided in the format of tagKeys/{tag_key_id} -> tagValues/{tag_value_id}.