pub struct GoogleFirestoreAdminV1SourceEncryptionOptions { /* private fields */ }Expand description
The configuration options for using the same encryption method as the source.
This type is not used in any activity, and only used as part of another schema.