pub struct GoogleFirestoreAdminV1SourceInfo {
pub backup: Option<GoogleFirestoreAdminV1BackupSource>,
pub operation: Option<String>,
}Expand description
Information about the provenance of this database.
This type is not used in any activity, and only used as part of another schema.
Fields
backup: Option<GoogleFirestoreAdminV1BackupSource>If set, this database was restored from the specified backup (or a snapshot thereof).
operation: Option<String>The associated long-running operation. This field may not be set after the operation has completed. Format: projects/{project}/databases/{database}/operations/{operation}.