pub struct GoogleFirestoreAdminV1Stats {
pub document_count: Option<i64>,
pub index_count: Option<i64>,
pub size_bytes: Option<i64>,
}Expand description
Backup specific statistics.
This type is not used in any activity, and only used as part of another schema.
Fields
document_count: Option<i64>Output only. The total number of documents contained in the backup.
index_count: Option<i64>Output only. The total number of index entries contained in the backup.
size_bytes: Option<i64>Output only. Summation of the size of all documents and index entries in the backup, measured in bytes.