GoogleFirestoreAdminV1TtlConfig

Struct GoogleFirestoreAdminV1TtlConfig 

pub struct GoogleFirestoreAdminV1TtlConfig {
    pub state: Option<String>,
}
The TTL (time-to-live) configuration for documents that have this Field set. Storing a timestamp value into a TTL-enabled field will be treated as the document’s absolute expiration time. Timestamp values in the past indicate that the document is eligible for immediate expiration. Using any other data type or leaving the field absent will disable expiration for the individual document.

This type is not used in any activity, and only used as part of another schema.

Fields

state: Option<String>

Output only. The state of the TTL configuration.