pub struct GoogleFirestoreAdminV1VectorConfig {
pub dimension: Option<i32>,
pub flat: Option<GoogleFirestoreAdminV1FlatIndex>,
}Expand description
The index configuration to support vector search operations
This type is not used in any activity, and only used as part of another schema.
Fields
dimension: Option<i32>Required. The vector dimension this configuration applies to. The resulting index will only include vectors of this dimension, and can be used for vector search with the same dimension.
flat: Option<GoogleFirestoreAdminV1FlatIndex>Indicates the vector index is a flat index.