pub struct GoogleFirestoreAdminV1WeeklyRecurrence {
pub day: Option<String>,
}Expand description
Represents a recurring schedule that runs on a specified day of the week. The time zone is UTC.
This type is not used in any activity, and only used as part of another schema.
Fields
day: Option<String>The day of week to run. DAY_OF_WEEK_UNSPECIFIED is not allowed.