pub struct Value {Show 14 fields
pub array_value: Option<ArrayValue>,
pub boolean_value: Option<bool>,
pub bytes_value: Option<Vec<u8>>,
pub double_value: Option<f64>,
pub field_reference_value: Option<String>,
pub function_value: Option<Function>,
pub geo_point_value: Option<LatLng>,
pub integer_value: Option<i64>,
pub map_value: Option<MapValue>,
pub null_value: Option<String>,
pub pipeline_value: Option<Pipeline>,
pub reference_value: Option<String>,
pub string_value: Option<String>,
pub timestamp_value: Option<DateTime<Utc>>,
}Expand description
A message that can hold any of the supported value types.
This type is not used in any activity, and only used as part of another schema.
Fields
array_value: Option<ArrayValue>An array value. Cannot directly contain another array value, though can contain a map which contains another array.
boolean_value: Option<bool>A boolean value.
bytes_value: Option<Vec<u8>>A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes are considered by queries.
double_value: Option<f64>A double value.
field_reference_value: Option<String>Value which references a field. This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document. Requires: * Must follow field reference limitations. * Not allowed to be used when writing documents.
function_value: Option<Function>A value that represents an unevaluated expression. Requires: * Not allowed to be used when writing documents.
geo_point_value: Option<LatLng>A geo point value representing a point on the surface of Earth.
integer_value: Option<i64>An integer value.
map_value: Option<MapValue>A map value.
null_value: Option<String>A null value.
pipeline_value: Option<Pipeline>A value that represents an unevaluated pipeline. Requires: * Not allowed to be used when writing documents.
reference_value: Option<String>A reference to a document. For example: projects/{project_id}/databases/{database_id}/documents/{document_path}.
string_value: Option<String>A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes of the UTF-8 representation are considered by queries.
timestamp_value: Option<DateTime<Utc>>A timestamp value. Precise only to microseconds. When stored, any additional precision is rounded down.