[][src]Struct google_firestore1::CommitRequest

pub struct CommitRequest {
    pub writes: Option<Vec<Write>>,
    pub transaction: Option<String>,
}

The request for Firestore.Commit.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

writes: Option<Vec<Write>>

The writes to apply.

Always executed atomically and in order.

transaction: Option<String>

If set, applies all writes in this transaction, and commits it.