[][src]Struct google_firestore1::ListCollectionIdsResponse

pub struct ListCollectionIdsResponse {
    pub next_page_token: Option<String>,
    pub collection_ids: Option<Vec<String>>,
}

The response from Firestore.ListCollectionIds.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

next_page_token: Option<String>

A page token that may be used to continue the list.

collection_ids: Option<Vec<String>>

The collection ids.