[][src]Struct google_firestore1::RunQueryRequest

pub struct RunQueryRequest {
    pub new_transaction: Option<TransactionOptions>,
    pub transaction: Option<String>,
    pub structured_query: Option<StructuredQuery>,
    pub read_time: Option<String>,
}

The request for Firestore.RunQuery.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

new_transaction: Option<TransactionOptions>

Starts a new transaction and reads the documents. Defaults to a read-only transaction. The new transaction ID will be returned as the first response in the stream.

transaction: Option<String>

Reads documents in a transaction.

structured_query: Option<StructuredQuery>

A structured query.

read_time: Option<String>

Reads documents as they were at the given time. This may not be older than 60 seconds.