[][src]Struct google_firestore1::Write

pub struct Write {
    pub current_document: Option<Precondition>,
    pub update_transforms: Option<Vec<FieldTransform>>,
    pub update_mask: Option<DocumentMask>,
    pub delete: Option<String>,
    pub update: Option<Document>,
    pub transform: Option<DocumentTransform>,
}

A write on a document.

This type is not used in any activity, and only used as part of another schema.

Fields

current_document: Option<Precondition>

An optional precondition on the document.

The write will fail if this is set and not met by the target document.

update_transforms: Option<Vec<FieldTransform>>

The transforms to perform after update.

This field can be set only when the operation is update. If present, this write is equivalent to performing update and transform to the same document atomically and in order.

update_mask: Option<DocumentMask>

The fields to update in this write.

This field can be set only when the operation is update. If the mask is not set for an update and the document exists, any existing data will be overwritten. If the mask is set and the document on the server has fields not covered by the mask, they are left unchanged. Fields referenced in the mask, but not present in the input document, are deleted from the document on the server. The field paths in this mask must not contain a reserved field name.

delete: Option<String>

A document name to delete. In the format: projects/{project_id}/databases/{database_id}/documents/{document_path}.

update: Option<Document>

A document to write.

transform: Option<DocumentTransform>

Applies a transformation to a document.