[][src]Struct google_firestore1::WriteResponse

pub struct WriteResponse {
    pub write_results: Option<Vec<WriteResult>>,
    pub stream_token: Option<String>,
    pub commit_time: Option<String>,
    pub stream_id: Option<String>,
}

The response for Firestore.Write.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

write_results: Option<Vec<WriteResult>>

The result of applying the writes.

This i-th write result corresponds to the i-th write in the request.

stream_token: Option<String>

A token that represents the position of this response in the stream. This can be used by a client to resume the stream at this point.

This field is always set.

commit_time: Option<String>

The time at which the commit occurred. Any read with an equal or greater read_time is guaranteed to see the effects of the write.

stream_id: Option<String>

The ID of the stream. Only set on the first message, when a new stream was created.