pub struct GoogleFirestoreAdminV1BulkDeleteDocumentsRequest {
pub collection_ids: Option<Vec<String>>,
pub namespace_ids: Option<Vec<String>>,
}Expand description
The request for FirestoreAdmin.BulkDeleteDocuments. When both collection_ids and namespace_ids are set, only documents satisfying both conditions will be deleted. Requests with namespace_ids and collection_ids both empty will be rejected. Please use FirestoreAdmin.DeleteDatabase instead.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- databases bulk delete documents projects (request)
Fields
collection_ids: Option<Vec<String>>Optional. IDs of the collection groups to delete. Unspecified means all collection groups. Each collection group in this list must be unique.
namespace_ids: Option<Vec<String>>Optional. Namespaces to delete. An empty list means all namespaces. This is the recommended usage for databases that don’t use namespaces. An empty string element represents the default namespace. This should be used if the database has data in non-default namespaces, but doesn’t want to delete from them. Each namespace in this list must be unique.