[−][src]Struct google_firestore1::ListCollectionIdsRequest
The request for Firestore.ListCollectionIds.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
page_token: Option<String>A page token. Must be a value from ListCollectionIdsResponse.
page_size: Option<i32>The maximum number of results to return.